xtable.SK: xtable method for 'SK' objects.

View source: R/xtable.SK.R

xtable.SKR Documentation

xtable method for SK objects.

Description

Convert an SK object to an xtable.SK object, which can then be printed as a LaTeX or HTML table. This function provides an additional method for the xtable function from the xtable package.

Usage


## S3 method for class 'SK'
xtable(x, ...)

Arguments

x

A given object of the class SK.

...

Further arguments (required by xtable::xtable).

Author(s)

Faria, J. C. (joseclaudio.faria@gmail.com)
Jelihovschi, E. G. (eniojelihovs@gmail.com)
Allaman, I. B. (ivanalaman@gmail.com)

See Also

xtable

Examples

data(RCBD)

lm1 <- with(RCBD,
            lm(y ~ blk + tra,
               data=dfm))

sk1 <- SK(lm1,
          which='tra')

tb <- xtable(sk1)
## Not run: 
  print(tb)

## End(Not run)

ScottKnott documentation built on May 24, 2026, 5:06 p.m.