| boxplot.SK | R Documentation |
S3 method to plot SK objects.
## S3 method for class 'SK'
boxplot(x,
mean.type = c('line', 'point', 'none'),
xlab = NULL,
mean.col = 'gray',
mean.pch = 1,
mean.lwd = 1,
mean.lty = 1,
args.legend = NULL, ...)
x |
A |
mean.type |
The type of mean representation to be plotted. The default is “line”. |
xlab |
A label for the ‘x’ axis. |
mean.col |
A vector of colors for the means representation. |
mean.pch |
A vector of plotting symbols or characters. Used only when |
mean.lwd |
Line width of mean. |
mean.lty |
Line type of the mean. Used only when |
args.legend |
List of additional arguments to be passed to |
... |
Optional plotting parameters. |
The boxplot.SK function is an S3 method for plotting SK
objects. It extends the generic boxplot function by overlaying
Scott & Knott group labels above the plot frame and drawing the treatment
mean within each box.
Faria, J. C. (joseclaudio.faria@gmail.com)
Jelihovschi, E. G. (eniojelihovs@gmail.com)
Allaman, I. B. (ivanalaman@gmail.com)
Murrell, P. (2005) R Graphics. Chapman and Hall/CRC Press.
boxplot
##
## Examples: Completely Randomized Design (CRD)
## More details: demo(package='SK')
##
library(ScottKnott)
data(CRD1)
## From: formula
## Simple
sk1 <- SK(y ~ x,
data=CRD1$dfm,
which='x')
boxplot(sk1)
## A little more elaborate
boxplot(sk1,
mean.lwd=1.3,
mean.col='red')
## More customisation
boxplot(sk1,
mean.lwd=1.3,
mean.lty=2,
mean.col='red',
args.legend=list(x='bottomleft'))
## With point type
boxplot(sk1,
mean.type='point')
boxplot(sk1,
mean.type='point',
mean.pch=19,
cex=1.5,
mean.col='red')
## With a different point symbol
boxplot(sk1,
mean.type='point',
mean.pch='+',
cex=2,
mean.col='blue',
args.legend=list(x='bottomleft'))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.