| xtable.SK | R Documentation |
SK objects.
Convert an SK object to an xtable.SK object, which can then be printed as a LaTeX or HTML table. This function provides an additional method for the xtable function from the xtable package.
## S3 method for class 'SK'
xtable(x, ...)
x |
A given object of the class |
... |
Further arguments (required by |
Faria, J. C. (joseclaudio.faria@gmail.com)
Jelihovschi, E. G. (eniojelihovs@gmail.com)
Allaman, I. B. (ivanalaman@gmail.com)
xtable
data(RCBD)
lm1 <- with(RCBD,
lm(y ~ blk + tra,
data=dfm))
sk1 <- SK(lm1,
which='tra')
tb <- xtable(sk1)
## Not run:
print(tb)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.